export var backgroundColor = '#848484';
export function getPositionOffset(placing, rect, offset) {
    if (offset === void 0) { offset = 12; }
    switch (placing) {
        case 'top':
            return {
                top: rect.top - offset,
                transform: 'translate(-50%, -100%)',
                left: rect.left + rect.width / 2,
            };
        case 'right':
            return {
                top: rect.top + rect.height / 2,
                transform: 'translate(0, -50%)',
                left: rect.left + rect.width + offset,
            };
        case 'left':
            return {
                top: rect.top + rect.height / 2,
                transform: 'translate(-100%, -50%)',
                left: rect.left - offset,
            };
        default:
            return {
                top: rect.top + rect.height,
                left: rect.left + rect.width / 2 + offset,
                transform: 'translate(-50%, 0)',
            };
    }
}
export function getRect(element) {
    if (element === null) {
        return document.body.getBoundingClientRect();
    }
    return element.getBoundingClientRect();
}
export function getAutoPlacing(rect, placing, width) {
    var bodyClientRect = document.body.getBoundingClientRect();
    if (bodyClientRect.width - rect.right < width / 2 || rect.left < width) {
        var rightSide = bodyClientRect.width - rect.right - width / 2;
        var leftSide = rect.left - width;
        return rightSide > leftSide ? 'right' : 'left';
    }
    return placing;
}
export function getFlexDirection(placing) {
    switch (placing) {
        case 'bottom':
            return { flexDirection: 'column' };
        case 'top':
            return { flexDirection: 'column-reverse' };
        case 'right':
            return { flexDirection: 'row' };
        default:
            return { flexDirection: 'row-reverse' };
    }
}
export function getArrow(placing) {
    var oppositeDirectionValue = '7px solid transparent';
    var currentDirectionValue = "12px solid " + backgroundColor;
    var currentDirectionMargin = '-2px';
    switch (placing) {
        case 'top':
            return {
                borderLeft: oppositeDirectionValue,
                borderRight: oppositeDirectionValue,
                borderTop: currentDirectionValue,
                marginTop: currentDirectionMargin,
            };
        case 'right':
            return {
                borderTop: oppositeDirectionValue,
                borderBottom: oppositeDirectionValue,
                borderRight: currentDirectionValue,
                marginRight: currentDirectionMargin,
            };
        case 'bottom':
            return {
                borderRight: oppositeDirectionValue,
                borderLeft: oppositeDirectionValue,
                borderBottom: currentDirectionValue,
                marginBottom: currentDirectionMargin,
            };
        default:
            return {
                borderTop: oppositeDirectionValue,
                borderBottom: oppositeDirectionValue,
                borderLeft: currentDirectionValue,
                marginLeft: currentDirectionMargin,
            };
    }
}
